BaseIntervalScorer
==============================================

.. currentmodule:: skchange.base

.. autoclass:: BaseIntervalScorer

.. include:: skchange.base.BaseIntervalScorer.examples

.. raw:: html

    <div class="clearer"></div>